@@ -23,6 +23,7 @@ from eolie.logger import Logger
 
 
 class Server:
+
     def __init__(self, con, path):
         method_outargs = {}
         method_inargs = {}
@@ -32,7 +33,7 @@ class Server:
                 method_outargs[method.name] = '(' + ''.join(
                               [arg.signature for arg in method.out_args]) + ')'
                 method_inargs[method.name] = tuple(
-                                       arg.signature for arg in method.in_args)
+                    arg.signature for arg in method.in_args)
 
             con.register_object(object_path=path,
                                 interface_info=interface,
@@ -71,7 +72,7 @@ class Server:
                 invocation.return_value(variant)
             else:
                 invocation.return_value(None)
-        except Exception as e:
+        except:
             pass
 
 
@@ -159,12 +160,12 @@ class ProxyExtensionServer(Server):
         addr = Gio.dbus_address_get_for_bus_sync(Gio.BusType.SESSION, None)
         self.__bus = None
         Gio.DBusConnection.new_for_address(
-                               addr,
-                               Gio.DBusConnectionFlags.AUTHENTICATION_CLIENT |
-                               Gio.DBusConnectionFlags.MESSAGE_BUS_CONNECTION,
-                               None,
-                               None,
-                               self.__on_bus_new_for_address)
+            addr,
+            Gio.DBusConnectionFlags.AUTHENTICATION_CLIENT |
+            Gio.DBusConnectionFlags.MESSAGE_BUS_CONNECTION,
+            None,
+            None,
+            self.__on_bus_new_for_address)
         form_extension.connect("submit-form", self.__on_submit_form)
         page.connect("send-request", self.__on_send_request)
         page.connect("context-menu", self.__on_context_menu)
@@ -253,7 +254,8 @@ class ProxyExtensionServer(Server):
             (forms, textareas) = self.__form_extension.get_elements(elements)
             for form in forms:
                 if form["username"].get_name() == userform:
-                    self.__helper.get(self.__form_extension.get_form_uri(form),
+                    uri = self.__form_extension.get_form_uri(form["element"])
+                    self.__helper.get(uri,
                                       userform,
                                       form["password"].get_name(),
                                       self.__form_extension.set_input_forms,
@@ -477,11 +479,11 @@ class ProxyExtensionServer(Server):
             if element.get_input_type() == "password" and\
                     self.__bus is not None:
                 self.__bus.emit_signal(
-                              None,
-                              PROXY_PATH,
-                              self.__proxy_bus,
-                              "UnsecureFormFocused",
-                              None)
+                    None,
+                    PROXY_PATH,
+                    self.__proxy_bus,
+                    "UnsecureFormFocused",
+                    None)
 
     def __on_blur(self, element, event):
         """
@@ -510,11 +512,11 @@ class ProxyExtensionServer(Server):
                                     parsed_form_uri.netloc)
             args = GLib.Variant("(ss)", (element.get_name(), form_uri))
             self.__bus.emit_signal(
-                              None,
-                              PROXY_PATH,
-                              self.__proxy_bus,
-                              "ShowCredentials",
-                              args)
+                None,
+                PROXY_PATH,
+                self.__proxy_bus,
+                "ShowCredentials",
+                args)
         self.__mouse_down_element = element
 
     def __on_input(self, element, event):
@@ -538,6 +540,8 @@ class ProxyExtensionServer(Server):
         """
         self.__on_input_timeout_id = None
         new_value = element.get_value()
+        if new_value is None:
+            return
         item = LinkedList("", None, None)
         if element in self.__elements_history.keys():
             item = self.__elements_history[element]
@@ -555,10 +559,6 @@ class ProxyExtensionServer(Server):
         (forms, textareas) = self.__form_extension.get_elements(elements)
         self.__add_event_listeners(forms, textareas, webpage)
         for form in forms:
-            form["element"].add_event_listener(
-                                          "submit",
-                                          self.__form_extension.on_form_submit,
-                                          False)
             self.__form_extension.set_credentials(form, webpage)
 
     def __on_context_menu(self, webpage, context_menu, hit):
@@ -579,11 +579,11 @@ class ProxyExtensionServer(Server):
         """
         if self.__bus is not None:
             self.__bus.emit_signal(
-                                  None,
-                                  PROXY_PATH,
-                                  self.__proxy_bus,
-                                  "AskSaveCredentials",
-                                  variant)
+                None,
+                PROXY_PATH,
+                self.__proxy_bus,
+                "AskSaveCredentials",
+                variant)
 
     def __on_notify_uri(self, webpage, param):
         """
