@@ -67,6 +67,8 @@ class WebView(WebKit2.WebView):
         """
         webview = WebKit2.WebView.new_with_related_view(related)
         webview.__class__ = WebViewMeta
+        # Related view are linked to related context, can't do anything about
+        # this
         webview.__init(related, related.context,
                        related.content_manager, window, None)
         return webview
@@ -159,17 +161,24 @@ class WebView(WebKit2.WebView):
             Set delayed uri
             @param uri as str
         """
-        self._uri = uri
+        self.__uri = uri
         self.emit("uri-changed", uri)
 
     def update_spell_checking(self, uri):
         """
             Update spell checking
         """
+        context = self.get_context()
         codes = App().websettings.get_languages(uri)
         # If None, default user language
-        if codes is not None:
-            self.get_context().set_spell_checking_languages(codes)
+        if codes is None:
+            locales = GLib.get_language_names()
+            try:
+                codes = [locales[0].split(".")[0]]
+            except:
+                codes = None
+        if context.get_spell_checking_languages() != codes:
+            context.set_spell_checking_languages(codes)
 
     def add_text_entry(self, text):
         """
@@ -253,14 +262,14 @@ class WebView(WebKit2.WebView):
             self._window.container.popup_webview(webview, True)
             GLib.idle_add(webview.load_uri, uri)
         else:
-            self._new_pages_opened += 1
+            self.__new_pages_opened += 1
             webview = self._window.container.add_webview(
                 uri,
                 loading_type,
                 self.ephemeral,
                 None,
                 self.atime -
-                self._new_pages_opened)
+                self.__new_pages_opened)
             webview.set_parent(self)
             self.add_child(webview)
 
@@ -384,7 +393,7 @@ class WebView(WebKit2.WebView):
         """
         uri = self.get_uri()
         if uri is None:
-            uri = self._uri
+            uri = self.__uri
         return uri
 
     @property
@@ -444,14 +453,13 @@ class WebView(WebKit2.WebView):
         self.__atime = 0
         self.__children = []
         self.__parent = None
-        self._new_pages_opened = 0
+        self.__new_pages_opened = 0
         # WebKitGTK doesn't provide an API to get selection, so try to guess
         # it from clipboard FIXME Get it from extensions
         self.__selection = ""
         self._readable_content = ""
-        self._uri = None
+        self.__uri = None
         self._title = None
-        self._navigation_uri = None
         self.__related_view = related_view
         self._shown = False
         self.set_hexpand(True)
@@ -481,7 +489,6 @@ class WebView(WebKit2.WebView):
                                   App().settings.get_value(
                                       "font-serif").get_string())
         settings.set_property("auto-load-images", True)
-        settings.set_property("enable-media-stream", True)
         settings.set_property("enable-site-specific-quirks", True)
         settings.set_property("allow-universal-access-from-file-urls", False)
         settings.set_property("allow-file-access-from-file-urls", False)
@@ -529,77 +536,72 @@ class WebView(WebKit2.WebView):
         """
         webview = WebView.new_with_related_view(related, self._window)
         webview.set_atime(related.atime - 1)
+        elapsed = time() - related._last_click_time
         webview.connect("ready-to-show",
                         self.__on_ready_to_show,
                         related,
-                        navigation_action)
+                        navigation_action,
+                        elapsed)
         webview.set_parent(self)
         self.add_child(webview)
         return webview
 
-    def __on_ready_to_show(self, webview, related, navigation_action):
+    def __on_ready_to_show(self, webview, related, navigation_action, elapsed):
         """
             Add a new webview with related
             @param webview as WebView
             @param related as WebView
             @param navigation_action as WebKit2.NavigationAction
+            @param elapsed as float
         """
-        GLib.idle_add(self.__wait_for_uri, webview, related, navigation_action)
-
-    def __wait_for_uri(self, webview, related, navigation_action):
-        """
-            Add a new webview with related as soon an URI is available
-            @param webview as WebView
-            @param related as WebView
-            @param navigation_action as WebKit2.NavigationAction
-        """
-        uri = webview.uri
-        # We need an URI for adblocking
-        if not webview.uri:
-            GLib.idle_add(self.__wait_for_uri, webview,
-                          related, navigation_action)
-            return
-        # Block ads
-        parsed = urlparse(uri)
-        if App().settings.get_value("adblock") and\
-                parsed.scheme in ["http", "https"] and\
-                not App().adblock_exceptions.find_parsed(parsed):
-            if App().adblock.is_netloc_blocked(parsed.netloc) or\
-                    App().adblock.is_uri_blocked(uri,
-                                                 parsed.netloc):
-                Logger.debug("WebView::__wait_for_uri(): blocking %s ->%s",
-                             uri, self.uri)
-                webview.destroy()
+        def on_load_changed(webview, event):
+            parsed = urlparse(webview.uri)
+            # First, adblocking
+            if not parsed.netloc:
                 return
-        popup_block = App().settings.get_value("popupblock")
-        if related.uri is not None:
-            parsed_related = urlparse(related.uri)
-            elapsed = time() - related._last_click_time
-            exception = elapsed < 0.5 or\
-                App().popup_exceptions.find_parsed(parsed_related)
-        else:
-            exception = False
+            if App().settings.get_value("adblock") and\
+                    parsed.scheme in ["http", "https"] and\
+                    not App().adblock_exceptions.find_parsed(parsed):
+                if App().adblock.is_netloc_blocked(parsed.netloc) or\
+                        App().adblock.is_uri_blocked(webview.uri,
+                                                     parsed.netloc):
+                    webview.destroy()
+                    return
+            if event != WebKit2.LoadEvent.FINISHED:
+                return
+            else:
+                webview.disconnect_by_func(on_load_changed)
 
-        if not exception and popup_block and\
-                navigation_action.get_navigation_type() in [
-                    WebKit2.NavigationType.OTHER,
-                    WebKit2.NavigationType.RELOAD,
-                    WebKit2.NavigationType.BACK_FORWARD]:
-            related.add_popup(webview)
-            webview.connect("close", self.__on_popup_close, related)
-            if related == self._window.container.current.webview:
-                self._window.toolbar.title.show_indicator(
-                    Indicator.POPUPS)
-            return
-        properties = webview.get_window_properties()
-        if (properties.get_toolbar_visible() or
-                properties.get_scrollbars_visible()) and\
-                not self._window.modifiers & Gdk.ModifierType.SHIFT_MASK:
-            self._window.container.add_webview_with_new_view(
-                webview,
-                LoadingType.FOREGROUND)
-        else:
-            self._window.container.popup_webview(webview, True)
+            # Then popup blocking
+            popup_block = App().settings.get_value("popupblock")
+            if related.uri is not None:
+                parsed_related = urlparse(related.uri)
+                exception = elapsed < 1.0 or\
+                    App().popup_exceptions.find_parsed(parsed_related)
+            else:
+                exception = False
+
+            properties = webview.get_window_properties()
+            if not exception and popup_block and\
+                    navigation_action.get_navigation_type() in [
+                        WebKit2.NavigationType.OTHER,
+                        WebKit2.NavigationType.RELOAD,
+                        WebKit2.NavigationType.BACK_FORWARD]:
+                related.add_popup(webview)
+                webview.connect("close", self.__on_popup_close, related)
+                if related == self._window.container.current.webview:
+                    self._window.toolbar.title.show_indicator(
+                        Indicator.POPUPS)
+            elif (properties.get_toolbar_visible() or
+                    properties.get_scrollbars_visible()) and\
+                    not self._window.modifiers == Gdk.KEY_Shift_L:
+                self._window.container.add_webview_with_new_view(
+                    webview,
+                    LoadingType.FOREGROUND)
+            else:
+                self._window.container.popup_webview(webview, True)
+
+        webview.connect("load-changed", on_load_changed)
 
     def __on_popup_close(self, webview, related):
         """
@@ -628,7 +630,9 @@ class WebViewMeta(WebViewNavigation, WebView, WebViewErrors,
             @param webview as WebView
             @param event as WebKit2.LoadEvent
         """
-        self._uri = webview.get_uri()
+        self.__uri = webview.get_uri()
+        if event == WebKit2.LoadEvent.STARTED:
+            self.__new_pages_opened = 0
         WebViewNavigation._on_load_changed(self, webview, event)
         WebViewSignals._on_load_changed(self, webview, event)
         WebViewArtwork._on_load_changed(self, webview, event)
